import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { defaultEcogestureData } from 'tests/__mocks__/actionData.mock'
import {
  createMockEcolyoStore,
  mockChallengeState,
  mockProfileState,
} from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import ActionCard from '../ActionCard/ActionCard'
import ActionList from './ActionList'

const mockGetCustomActions = jest.fn()
const mockGetDefaultActions = jest.fn()

jest.mock('services/action.service', () => {
  return jest.fn(() => ({
    getCustomActions: mockGetCustomActions,
    getDefaultActions: mockGetDefaultActions,
  }))
})

describe('ActionList component', () => {
  it('should be rendered correctly', async () => {
    mockGetDefaultActions.mockResolvedValueOnce(defaultEcogestureData)
    const store = createMockEcolyoStore({
      challenge: { ...mockChallengeState },
      global: { fluidTypes: [0, 1, 2] },
      profile: mockProfileState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionList setSelectedAction={jest.fn()} setShowList={jest.fn()} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find(ActionCard)).toBeTruthy()
  })
})
