import { Button } from '@material-ui/core'
import EcogestureModal from 'components/Ecogesture/EcogestureModal/EcogestureModal'
import { UserActionState } from 'enums'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import { UserAction } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import { defaultEcogestureData } from 'tests/__mocks__/actionData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import ActionOnGoing from './ActionOnGoing'

describe('ActionOnGoing component', () => {
  const store = createMockEcolyoStore()
  const userAction: UserAction = {
    // TODO if ecogesture is null snapshot test is useless
    ecogesture: null,
    startDate: DateTime.local(2020, 1, 1)
      .setZone('utc', {
        keepLocalTime: true,
      })
      .startOf('day'),
    state: UserActionState.ONGOING,
  }
  it('should render correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on button open ecogesture Modal', async () => {
    const userAction1: UserAction = {
      ecogesture: defaultEcogestureData[1],
      startDate: null,
      state: UserActionState.ONGOING,
    }

    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction1} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(EcogestureModal).exists()).toBeTruthy()
  })
})
