import AxisBottom from 'components/Charts/AxisBottom'
import AxisRight from 'components/Charts/AxisRight'
import Bar from 'components/Charts/Bar'
import { useChartResize } from 'components/Hooks/useChartResize'
import { scaleBand, ScaleBand, scaleLinear, ScaleLinear } from 'd3-scale'
import { FluidType, TimeStep } from 'enums'
import { DateTime } from 'luxon'
import { Dataload } from 'models'
import React, { useRef } from 'react'
import './elecHalfHourMonthlyAnalysis.scss'

interface ElecHalfHourChartProps {
  dataLoad: Dataload[]
  isWeekend: boolean
}

const ElecHalfHourChart = ({ dataLoad, isWeekend }: ElecHalfHourChartProps) => {
  const chartContainer = useRef<HTMLDivElement>(null)
  const { height, width } = useChartResize(chartContainer, false, 170, 940)
  const marginLeft = 10
  const marginRight = 60
  const marginTop = 0
  const marginBottom = 30
  const getContentWidth = () => width - marginLeft - marginRight
  const getContentHeight = () => height - marginTop - marginBottom

  const getMaxLoad = () => {
    if (!dataLoad || dataLoad.length === 0) return 0
    return Math.max(...dataLoad.map(({ value }) => value))
  }

  const xScale: ScaleBand<string> = scaleBand()
    .domain(
      dataLoad.map((d: Dataload) =>
        d.date.toLocaleString(DateTime.DATETIME_SHORT)
      )
    )
    .range([0, getContentWidth()])
    .padding(0.1)

  const yScale: ScaleLinear<number, number> = scaleLinear()
    .domain([0, getMaxLoad()])
    .range([getContentHeight(), 0])

  return (
    <div className="graph-elec-half-hour" ref={chartContainer}>
      <svg width={width} height={height}>
        <AxisRight
          fluidType={FluidType.ELECTRICITY}
          yScale={yScale}
          width={width}
          marginRight={marginRight}
          marginTop={marginTop}
          isAnalysis={true}
        />
        <g transform={`translate(${10},${0})`}>
          {dataLoad.map((value, index) => (
            <Bar
              key={index}
              index={index}
              dataload={value}
              compareDataload={null}
              fluidType={FluidType.ELECTRICITY}
              timeStep={TimeStep.HALF_AN_HOUR}
              compare={false}
              xScale={xScale}
              yScale={yScale}
              height={getContentHeight()}
              isSwitching={false}
              isDuel={false}
              weekdays={isWeekend ? 'weekend' : 'week'}
            />
          ))}
        </g>
        <AxisBottom
          data={dataLoad}
          timeStep={TimeStep.HALF_AN_HOUR}
          xScale={xScale}
          height={height}
          marginLeft={marginLeft}
          marginBottom={marginBottom}
          isDuel={false}
        />
      </svg>
    </div>
  )
}

export default ElecHalfHourChart
