import { IconButton } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { PerformanceIndicator } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import {
  mockDataLoadEnedisAnalysis,
  mockEnedisMonthlyAnalysisArray,
} from 'tests/__mocks__/enedisMonthlyAnalysisData.mock'
import { allLastFluidPrices } from 'tests/__mocks__/fluidPrice.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import ElecHalfHourMonthlyAnalysis from './ElecHalfHourMonthlyAnalysis'

jest.mock('components/Hooks/useExploration', () => {
  return () => ['', jest.fn()]
})

jest.mock(
  'components/Analysis/ElecHalfHourMonthlyAnalysis/ElecHalfHourChart',
  () => 'mock-elechalfhourchart'
)
jest.mock(
  'components/Analysis/ElecHalfHourMonthlyAnalysis/ElecInfoModal',
  () => 'mock-elecinfomodal'
)

const mockCheckDoctypeEntries = jest.fn()
jest.mock('services/consumption.service', () => {
  return jest.fn(() => ({
    checkDoctypeEntries: mockCheckDoctypeEntries,
  }))
})
const mockGetEnedisMonthlyAnalysisByDate = jest.fn()
const mockAggregateValuesToDataLoad = jest.fn()
jest.mock('services/enedisMonthlyAnalysisData.service', () => {
  return jest.fn(() => ({
    getEnedisMonthlyAnalysisByDate: mockGetEnedisMonthlyAnalysisByDate,
    aggregateValuesToDataLoad: mockAggregateValuesToDataLoad,
  }))
})
const mockPerfIndicator: PerformanceIndicator = {
  value: 10,
  compareValue: null,
  percentageVariation: null,
  price: null,
}
const mockGetPrices = jest.fn()
jest.mock('services/fluidsPrices.service', () => {
  return jest.fn(() => ({
    getPrices: mockGetPrices,
  }))
})

describe('ElecHalfHourMonthlyAnalysis component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly when isHalfHourActivated is false', async () => {
    mockCheckDoctypeEntries.mockResolvedValueOnce(false)
    mockGetPrices.mockResolvedValue(allLastFluidPrices[0])
    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourMonthlyAnalysis perfIndicator={mockPerfIndicator} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should be rendered correctly when isHalfHourActivated is true', async () => {
    mockCheckDoctypeEntries.mockResolvedValue(true)
    mockGetEnedisMonthlyAnalysisByDate.mockResolvedValueOnce(
      mockEnedisMonthlyAnalysisArray
    )
    mockAggregateValuesToDataLoad.mockResolvedValueOnce(
      mockDataLoadEnedisAnalysis
    )
    mockGetPrices.mockResolvedValue(allLastFluidPrices[0])

    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourMonthlyAnalysis perfIndicator={mockPerfIndicator} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should change from weekend to week', async () => {
    mockCheckDoctypeEntries.mockResolvedValue(true)
    mockGetEnedisMonthlyAnalysisByDate.mockResolvedValueOnce(
      mockEnedisMonthlyAnalysisArray
    )
    mockAggregateValuesToDataLoad.mockResolvedValueOnce(
      mockDataLoadEnedisAnalysis
    )
    mockGetPrices.mockResolvedValue(allLastFluidPrices[0])
    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourMonthlyAnalysis perfIndicator={mockPerfIndicator} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(IconButton).first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.week').exists()).toBeTruthy()
  })

  it('should call the ElecInfoModal with open = true when click on the button', async () => {
    mockCheckDoctypeEntries.mockResolvedValue(true)
    mockGetEnedisMonthlyAnalysisByDate.mockResolvedValueOnce(
      mockEnedisMonthlyAnalysisArray
    )
    mockAggregateValuesToDataLoad.mockReturnValueOnce(
      mockDataLoadEnedisAnalysis
    )
    mockGetPrices.mockResolvedValue(allLastFluidPrices[0])

    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourMonthlyAnalysis perfIndicator={mockPerfIndicator} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.showmodal').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-elecinfomodal').prop('open')?.valueOf()).toBe(
      true
    )
  })
})
