import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import './noAnalysisModal.scss'

const NoAnalysisModal = ({
  open,
  onClose,
}: {
  open: boolean
  onClose: React.Dispatch<React.SetStateAction<boolean>>
}) => {
  const { t } = useI18n()
  const navigate = useNavigate()

  const goToConsumption = () => {
    navigate('/consumption')
  }

  const close = () => {
    onClose(false)
  }

  return (
    <Dialog
      open={open}
      onClose={close}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('analysis_error_modal.accessibility.window_title')}
      </div>
      <div className="em-root analysis-error-container">
        <div className="analysis-error-title text-20-bold">
          {t('analysis_error_modal.title')}
        </div>
        <div className="analysis-error-message text-16-normal">
          {t('analysis_error_modal.message')}
        </div>
        <div className="analysis-error-button">
          <Button
            aria-label={t(
              'analysis_error_modal.accessibility.button_understood'
            )}
            onClick={close}
            classes={{
              root: 'btn-secondary-positive',
              label: 'text-16-normal',
            }}
          >
            {t('analysis_error_modal.understood')}
          </Button>
          <Button
            aria-label={t(
              'analysis_error_modal.accessibility.button_goto_konnector'
            )}
            onClick={goToConsumption}
            classes={{
              root: 'btn-highlight',
              label: 'text-16-bold',
            }}
          >
            {t('analysis_error_modal.go_to_conso')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default NoAnalysisModal
