import { Button } from '@material-ui/core'
import { FluidType } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import UsageEventService from 'services/usageEvent.service'
import {
  createMockEcolyoStore,
  mockChallengeState,
  mockGlobalState,
} from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import ChallengeNoFluidModal from '../ChallengeNoFluidModal/ChallengeNoFluidModal'
import ChallengeCardUnlocked from './ChallengeCardUnlocked'

const mockStartUserChallenge = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    startUserChallenge: mockStartUserChallenge,
  }))
})

jest.mock('services/usageEvent.service')
const mockAddEvent = jest.fn()
UsageEventService.addEvent = mockAddEvent

describe('ChallengeCardUnlocked component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('.challengeTitle').text()).toEqual('Simone\nVEILLE')
    expect(wrapper.find('.btn-duel-active').exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeFalsy()
  })

  it('should display ChallengeNoFluidModal when launching challenge without configured fluid', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.btn-duel-active').first().simulate('click')
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeTruthy()
  })

  it('should not display ChallengeNoFluidModal and update userChallenge when launching challenge with configured fluid', () => {
    const store = createMockEcolyoStore({
      global: {
        fluidTypes: [FluidType.ELECTRICITY],
        fluidStatus: [{ ...mockGlobalState.fluidStatus[0], status: 200 }],
      },
      challenge: mockChallengeState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.btn-duel-active').first().simulate('click')
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeFalsy()
    expect(mockStartUserChallenge).toHaveBeenCalledWith(userChallengeData[0])
  })

  it('should not be able to launch challenge if another one is active', () => {
    const store = createMockEcolyoStore({
      global: mockGlobalState,
      challenge: {
        ...mockChallengeState,
        currentChallenge: userChallengeData[1],
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    waitForComponentToPaint(wrapper)
    const resetButton = wrapper.find(Button).last()
    expect(resetButton.prop('disabled')).toBe(true)
  })
})
