import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import StepAddress from './StepAddress'

const mockHandleChange = jest.fn()

describe('StepAddress component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <StepAddress
          sgeState={mockGlobalState.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should change address value', () => {
    const wrapper = mount(
      <Provider store={store}>
        <StepAddress
          sgeState={mockGlobalState.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#address').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('address', '')
  })
  it('should change zipCode value', () => {
    const wrapper = mount(
      <Provider store={store}>
        <StepAddress
          sgeState={mockGlobalState.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#zipCode').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('zipCode', '', 5)
  })
  it('should have an existing zipCode value', () => {
    const wrapper = mount(
      <Provider store={store}>
        <StepAddress
          sgeState={{ ...mockGlobalState.sgeConnect, zipCode: 69200 }}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    expect(wrapper.find('#zipCode').first().props().value).toBe(69200)
  })
  it('should change city value', () => {
    const wrapper = mount(
      <Provider store={store}>
        <StepAddress
          sgeState={mockGlobalState.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#city').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('city', '')
  })
})
