import { FluidType } from 'enums'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import ConsumptionDetails from './ConsumptionDetails'

describe('ConsumptionDetails component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <ConsumptionDetails fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should not render connection card', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ConsumptionDetails fluidType={FluidType.MULTIFLUID} />
      </Provider>
    )
    expect(wrapper.contains('.fluidcard-link')).toBeFalsy()
  })
  it('should render one connection card', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ConsumptionDetails fluidType={FluidType.MULTIFLUID} />
      </Provider>
    )
    expect(wrapper.find('.fluidcard-link')).toBeTruthy()
  })
  it('should not render connection card and show multifluid link', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ConsumptionDetails fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    expect(wrapper.find('.multi-link')).toBeTruthy()
  })
})
