import { IconButton } from '@material-ui/core'
import { TimeStep } from 'enums'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import React from 'react'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import DateNavigator from './DateNavigator'

jest.mock(
  'components/DateNavigator/DateNavigatorFormat',
  () => 'mock-date-navigator-format'
)

const mockedDate = DateTime.local(2021, 7, 1)
  .setZone('utc', {
    keepLocalTime: true,
  })
  .startOf('day')
describe('DateNavigator component', () => {
  const mockHandleNextDate = jest.fn()
  const mockHandlePrevDate = jest.fn()
  beforeEach(() => {
    jest.clearAllMocks()
  })
  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <DateNavigator
        disableNext={false}
        disablePrev={false}
        handleNextDate={mockHandleNextDate}
        handlePrevDate={mockHandlePrevDate}
        navigatorDate={mockedDate}
        timeStep={TimeStep.MONTH}
      />
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  describe('should test navigation functions', () => {
    describe('should test previous arrow', () => {
      it('should call handlePrevDate', async () => {
        const wrapper = mount(
          <DateNavigator
            disableNext={false}
            disablePrev={false}
            handleNextDate={mockHandleNextDate}
            handlePrevDate={mockHandlePrevDate}
            navigatorDate={mockedDate}
            timeStep={TimeStep.MONTH}
          />
        )
        wrapper.find(IconButton).first().simulate('click')
        expect(mockHandlePrevDate).toHaveBeenCalledTimes(1)
      })

      it('should NOT call handlePrevDate if disablePrev is true', async () => {
        const wrapper = mount(
          <DateNavigator
            disableNext={false}
            disablePrev={true}
            handleNextDate={mockHandleNextDate}
            handlePrevDate={mockHandlePrevDate}
            navigatorDate={mockedDate}
            timeStep={TimeStep.MONTH}
          />
        )
        wrapper.find(IconButton).first().simulate('click')
        expect(mockHandlePrevDate).toHaveBeenCalledTimes(0)
      })
    })

    describe('should test next arrow', () => {
      it('should call mockHandleNextDate', async () => {
        const wrapper = mount(
          <DateNavigator
            disableNext={false}
            disablePrev={false}
            handleNextDate={mockHandleNextDate}
            handlePrevDate={mockHandlePrevDate}
            navigatorDate={mockedDate}
            timeStep={TimeStep.MONTH}
          />
        )
        wrapper.find(IconButton).at(1).simulate('click')
        expect(mockHandleNextDate).toHaveBeenCalledTimes(1)
      })

      it('should NOT call mockHandleNextDate if disableNext is true', async () => {
        const wrapper = mount(
          <DateNavigator
            disableNext={true}
            disablePrev={false}
            handleNextDate={mockHandleNextDate}
            handlePrevDate={mockHandlePrevDate}
            navigatorDate={mockedDate}
            timeStep={TimeStep.MONTH}
          />
        )
        wrapper.find(IconButton).at(1).simulate('click')
        expect(mockHandleNextDate).toHaveBeenCalledTimes(0)
      })
    })
  })
})
