import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React, { useEffect, useState } from 'react'
import { importIconById } from 'utils/utils'
import './duelEmptyValueModal.scss'

interface DuelEmptyValueModalProps {
  open: boolean
  handleCloseClick: () => void
}

const DuelEmptyValueModal = ({
  open,
  handleCloseClick,
}: DuelEmptyValueModalProps) => {
  const { t } = useI18n()
  const [emptyIcon, setEmptyIcon] = useState<string>(defaultIcon)
  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById('emptyValue', 'duel')
      setEmptyIcon(icon || defaultIcon)
    }

    handleEcogestureIcon()
  }, [])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper blue-border',
      }}
    >
      <div id="accessibility-title">
        {t('duel_empty_value_modal.accessibility.window_title')}
      </div>
      <div className="modal-empty-value-root">
        <Icon className="imgResult" icon={emptyIcon} size={208} />
        <div className="text-28-normal-uppercase modal-empty-value-title">
          {t('duel_empty_value_modal.title')}
        </div>
        <div className="text-18-normal">
          {t('duel_empty_value_modal.message')}
        </div>
        <Button
          aria-label={t('duel_empty_value_modal.accessibility.button_validate')}
          onClick={handleCloseClick}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-normal',
          }}
        >
          {t('duel_empty_value_modal.button')}
        </Button>
      </div>
    </Dialog>
  )
}

export default DuelEmptyValueModal
