import { UserChallengeState } from 'enums'
import { mount } from 'enzyme'
import { DateTime } from 'luxon'
import { UserChallenge } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import DuelResultModal from '../DuelResultModal/DuelResultModal'
import DuelOngoing from './DuelOngoing'

const mockUserChallengeUpdateFlag = jest.fn()
const mockIsChallengeDone = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
    isChallengeDone: mockIsChallengeDone,
  }))
})

jest.mock('components/Duel/DuelChart/DuelChart', () => 'mock-duelchart')
jest.mock(
  'components/Duel/DuelResultModal/DuelResultModal',
  () => 'mock-duelModal'
)

describe('DuelOngoing component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    mockIsChallengeDone.mockResolvedValue({
      isDone: false,
      isWin: false,
      isEmpty: false,
    })
    const wrapper = mount(
      <Provider store={store}>
        <DuelOngoing userChallenge={userChallengeData[0]} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.duel-title').text()).toEqual(
      userChallengeData[1].duel.title
    )
    expect(wrapper.find('.duel-goal').exists()).toBeTruthy()
    expect(wrapper.find('.duel-consumption').exists()).toBeTruthy()
    expect(wrapper.find('.duel-chart').exists()).toBeTruthy()
    expect(wrapper.find('.caption-icon').exists()).toBeTruthy()
  })

  it('should display the result Modal when duel is done', async () => {
    const updatedUserChallenge: UserChallenge = {
      ...userChallengeData[0],
      state: UserChallengeState.DUEL,
      startDate: DateTime.local().setZone('utc', { keepLocalTime: true }),
    }
    mockIsChallengeDone.mockResolvedValue({
      isDone: true,
      isWin: true,
    })
    mockUserChallengeUpdateFlag.mockResolvedValue(updatedUserChallenge)
    const wrapper = mount(
      <Provider store={store}>
        <DuelOngoing userChallenge={updatedUserChallenge} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find(DuelResultModal).exists()).toBeTruthy()
  })
})
