import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { FluidType, UserChallengeUpdateFlag } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import { formatNumberValues } from 'utils/utils'
import DuelUnlocked from './DuelUnlocked'

const mockUserChallengeUpdateFlag = jest.fn()
const mockGetUserChallengeDataload = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
    getUserChallengeDataload: mockGetUserChallengeDataload,
  }))
})

jest.mock('services/usageEvent.service')

describe('DuelUnlocked component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', () => {
    const average: string = formatNumberValues(
      userChallengeData[1].duel.threshold
    ).toString()
    const description: string =
      '"' +
      userChallengeData[1].duel.description.replace('#CONSUMPTION', average) +
      '"'
    const wrapper = mount(
      <Provider store={store}>
        <DuelUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('.duel-title').text()).toEqual(
      userChallengeData[1].duel.title
    )
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    expect(wrapper.find('.duel-description').text()).toEqual(description)
    expect(wrapper.find('.duel-average-info').exists()).toBeTruthy()
    expect(wrapper.find('.button-start').exists()).toBeTruthy()
  })

  it('should update userChallenge when launching duel with configured fluid', () => {
    const store = createMockEcolyoStore({
      global: {
        ...mockGlobalState,
        fluidTypes: [FluidType.ELECTRICITY],
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DuelUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.button-start').find(Button).simulate('click')
    expect(mockUserChallengeUpdateFlag).toHaveBeenCalledWith(
      userChallengeData[0],
      UserChallengeUpdateFlag.DUEL_START
    )
  })
})
