import Button from '@material-ui/core/Button'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import EcogestureEmptyList from './EcogestureEmptyList'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockChangeTab = jest.fn()
const mockHandleClick = jest.fn()

describe('EcogestureEmptyList component', () => {
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={true}
        isSelectionDone={false}
        handleReinitClick={mockHandleClick}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should return to all ecogestures', () => {
    const wrapper = mount(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={true}
        handleReinitClick={mockHandleClick}
      />
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockChangeTab).toHaveBeenCalledTimes(1)
  })
  it('should launch ecogesture form', () => {
    const wrapper = mount(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={false}
        handleReinitClick={mockHandleClick}
      />
    )
    wrapper.find(Button).at(1).simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-form')
  })
  it('should render doing text with empty list on completed selection', () => {
    const wrapper = mount(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={true}
        handleReinitClick={mockHandleClick}
      />
    )
    expect(wrapper.find('.text').first().text()).toBe(
      'ecogesture.emptyList.doing1_done'
    )
  })
  it('should render objective text with empty list on completed selection', () => {
    const wrapper = mount(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={true}
        isSelectionDone={true}
        handleReinitClick={mockHandleClick}
      />
    )
    expect(wrapper.find('.text').first().text()).toBe(
      'ecogesture.emptyList.obj1_done'
    )
  })
})
