import { Button, MenuItem } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import * as storeHooks from 'store/hooks'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import EcogestureList from './EcogestureList'

jest.mock(
  'components/Ecogesture/EcogestureCard/EcogestureCard',
  () => 'mock-ecogesturecard'
)

const mockHandleReinit = jest.fn()
const updateEcogestureFilter = jest.fn()
const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')
mockAppDispatch.mockImplementation(() => updateEcogestureFilter)

const store = createMockEcolyoStore()

describe('EcogesturesList component', () => {
  beforeAll(() => {
    mockAppDispatch.mockClear()
  })
  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
            handleReinitClick={mockHandleReinit}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should open the filter menu and select all ecogesture', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.filter-button').simulate('click')
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find('.filter-menu').exists()).toBeTruthy()
    wrapper.find(MenuItem).at(1).simulate('click')
    expect(updateEcogestureFilter).toHaveBeenCalledTimes(1)
  })

  it('should display the selection section', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={true}
            selectionTotal={50}
            selectionViewed={10}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.selection').exists()).toBeTruthy()
  })
})
