import { IconButton, Tab } from '@material-ui/core'
import EcogestureTabsView from 'components/Ecogesture/EcogestureTabsView'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.slice'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import EcogestureEmptyList from './EcogestureEmptyList/EcogestureEmptyList'
import EcogestureInitModal from './EcogestureInitModal/EcogestureInitModal'

const mockGetAllEcogestures = jest.fn()
const mockGetEcogestureListByProfile = jest.fn().mockResolvedValue([])
const mockInitEcogesture = jest.fn().mockResolvedValue(mockedEcogesturesData)
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getAllEcogestures: mockGetAllEcogestures,
    getEcogestureListByProfile: mockGetEcogestureListByProfile,
    initEcogesture: mockInitEcogesture,
  }))
})
const mockGetProfile = jest.fn()
const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    getProfile: mockGetProfile,
    updateProfile: mockUpdateProfile,
  }))
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock(
  'components/Ecogesture/EcogestureList/EcogestureList',
  () => 'mock-ecogesturelist'
)
jest.mock('components/Content/Content', () => 'mock-content')

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    search: '',
  }),
  useNavigate: () => jest.fn(),
}))

describe('EcogestureView component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(Tab).length).toBe(3)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should render ecogesture init modal', async () => {
    const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureInitModal).exists()).toBeTruthy()
    wrapper.find(IconButton).first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(updateProfileSpy).toHaveBeenCalledWith({
      haveSeenEcogestureModal: true,
    })
  })

  it('should render empty list', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureEmptyList).exists()).toBeTruthy()
  })

  it('should change tab', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find(Tab).first().simulate('click')
    mockGetAllEcogestures.mockResolvedValueOnce([])

    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureEmptyList).exists()).toBeTruthy()
  })
})
