/* eslint-disable react/display-name */
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import SingleEcogestureView from './SingleEcogestureView'

jest.mock(
  'components/Ecogesture/EfficiencyRating/EfficiencyRating',
  () => 'mock-EfficiencyRating'
)
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockGetEcogesturesByIds = jest.fn()
const mockUpdateEcogesture = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getEcogesturesByIds: mockGetEcogesturesByIds,
    updateEcogesture: mockUpdateEcogesture,
  }))
})

describe('SingleEcogesture component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should change doing status', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])

    const updatedEcogesture = { ...mockedEcogesturesData[0], doing: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.doing-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should change objective status', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])

    const updatedEcogesture = { ...mockedEcogesturesData[0], objective: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.objective-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should toggle more details', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find('.showMore').first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.showMore').text()).toBe('ecogesture_modal.show_less')
  })
})
