/* eslint-disable react/display-name */
import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { mockProfileEcogesture } from 'tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import EcogestureFormView from './EcogestureFormView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock(
  'components/EcogestureForm/EcogestureLaunchFormModal/EcogestureLaunchFormModal',
  () => 'mock-ecogesturelaunchmodal'
)
const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')
jest.mock('components/Content/Content', () => 'mock-content')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
  useLocation: () => ({
    search: '',
  }),
}))

describe('EcogestureFormView component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render singleChoice', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })
  it('should render profiletype form step because profiletype is completed', async () => {
    const store = createMockEcolyoStore({
      profile: { isProfileTypeCompleted: true },
      profileEcogesture: mockProfileEcogesture,
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.profile-type-container').exists()).toBeTruthy()
  })
  it('should go to next step', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('input').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })
  it('should go to previous step', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    // go first to next step
    await waitForComponentToPaint(wrapper)
    wrapper.find('input').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    // then go back
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })

  it('should handle form end', async () => {
    mockAppDispatch.mockReturnValue(jest.fn())
    jest
      .spyOn(React, 'useState')
      .mockImplementationOnce(() => [0, () => null])
      .mockImplementationOnce(() => [4, () => null])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(mockAppDispatch).toHaveBeenCalledTimes(2)
  })
})
