import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import EcogestureSelectionDetail from './EcogestureSelectionDetail'

const mockValidate = jest.fn()

describe('EcogestureSelectionDetail component', () => {
  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should toggle more details', async () => {
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find('.showMore').first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.showMore').text()).toBe('ecogesture_modal.show_less')
  })
  it('should call validate with objective to true', async () => {
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(0).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(true, false)
  })

  it('should call validate with doing to true', async () => {
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(false, true)
  })

  it('should call validate with objective and doing to false', async () => {
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(2).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(false, false)
  })
})
