import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import EcogestureSelectionRestart from './EcogestureSelectionRestart'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockRestart = jest.fn()

describe('EcogestureSelectionRestart component', () => {
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should call go to the ecogesture view when user click on the button', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    wrapper.find(Button).at(0).simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogestures?tab=0')
  })

  it('should call the restart when user click on the button', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    wrapper.find(Button).at(1).simulate('click')
    expect(mockRestart).toHaveBeenCalledTimes(1)
  })
})
