/* eslint-disable react/display-name */
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import EcogestureSelectionView from './EcogestureSelectionView'

const mockGetEcogestureListByProfile = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getEcogestureListByProfile: mockGetEcogestureListByProfile,
  }))
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionModal/EcogestureSelectionModal',
  () => 'mock-ecogestureSelectionModal'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionDetail/EcogestureSelectionDetail',
  () => 'mock-ecogestureSelectionDetail'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionRestart/EcogestureSelectionRestart',
  () => 'mock-ecogestureSelectionRestart'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionEnd/EcogestureSelectionEnd',
  () => 'mock-ecogestureSelectionEnd'
)

describe('EcogestureSelection component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([mockedEcogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render with the EcogestureSelectionModal', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([mockedEcogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureSelectionModal').exists()).toBeTruthy()
  })
  it('should render with the EcogestureSelectionDetail', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([mockedEcogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureSelectionDetail').exists()).toBeTruthy()
  })
  it('should render with the EcogestureSelectionEnd', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureSelectionEnd').exists()).toBeTruthy()
  })
})
