import { UserExplorationState } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { challengeStateData } from 'tests/__mocks__/challengeStateData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import ExplorationError from './ExplorationError'
import ExplorationFinished from './ExplorationFinished'
import ExplorationOngoing from './ExplorationOngoing'
import ExplorationView from './ExplorationView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

describe('ExplorationView', () => {
  it('should be rendered with ExplorationError component when unknown exploration state', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: 99,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({ challenge: updatedChallengeState })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationView />
      </Provider>
    )
    expect(wrapper.find(ExplorationError).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationOngoing component when exploration state = unlocked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.UNLOCKED,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({ challenge: updatedChallengeState })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationView />
      </Provider>
    )
    expect(wrapper.find(ExplorationOngoing).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationOngoing component when exploration state = ongoing', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.ONGOING,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({ challenge: updatedChallengeState })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationView />
      </Provider>
    )
    expect(wrapper.find(ExplorationOngoing).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationFinished component when exploration state = Done', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.DONE,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({ challenge: updatedChallengeState })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationView />
      </Provider>
    )
    expect(wrapper.find(ExplorationFinished).exists()).toBeTruthy()
  })
})
