import IconButton from '@material-ui/core/IconButton'
import Header from 'components/Header/Header'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import * as ModalAction from 'store/modal/modal.slice'
import { createMockEcolyoStore } from 'tests/__mocks__/store'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockSetHeaderHeight = jest.fn()

describe('Header component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <Header
          setHeaderHeight={mockSetHeaderHeight}
          desktopTitleKey="mockKey"
        />
      </Provider>
    )
    expect(wrapper.find('.header')).toHaveLength(1)
  })

  it('should display title and back button when desktopTitle key provided and displayBackArrow is true', () => {
    const wrapper = mount(
      <Provider store={store}>
        <Header
          desktopTitleKey="KEY"
          displayBackArrow={true}
          setHeaderHeight={mockSetHeaderHeight}
        />
      </Provider>
    )
    expect(wrapper.find('.header-text-desktop').first().text()).toEqual('KEY')
    expect(
      wrapper.find(IconButton).find('.header-back-button').first()
    ).toHaveLength(1)
  })

  it('should call handleClickBack when back button is clicked', () => {
    const wrapper = mount(
      <Provider store={store}>
        <Header
          desktopTitleKey="KEY"
          displayBackArrow={true}
          setHeaderHeight={mockSetHeaderHeight}
        />
      </Provider>
    )
    wrapper
      .find(IconButton)
      .find('.header-back-button')
      .first()
      .simulate('click')
    expect(mockedNavigate).toHaveBeenCalled()
  })

  it('should call handleClickFeedbacks when feedback button is clicked', () => {
    const wrapper = mount(
      <Provider store={store}>
        <Header
          setHeaderHeight={mockSetHeaderHeight}
          desktopTitleKey="mockKey"
        />
      </Provider>
    )
    const updateModalSpy = jest.spyOn(ModalAction, 'openFeedbackModal')
    wrapper
      .find(IconButton)
      .find('.header-feedbacks-button')
      .first()
      .simulate('click')
    expect(updateModalSpy).toHaveBeenCalledWith(true)
  })
})
