import { useClient } from 'cozy-client'
import { UserExplorationState } from 'enums'
import { UserExploration } from 'models'
import { Dispatch, SetStateAction, useEffect, useState } from 'react'
import ExplorationService from 'services/exploration.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { toggleChallengeExplorationNotification } from 'store/global/global.slice'
import { useAppDispatch, useAppSelector } from 'store/hooks'

const useExploration = (): [string, Dispatch<SetStateAction<string>>] => {
  const client = useClient()
  const dispatch = useAppDispatch()
  const { currentChallenge } = useAppSelector(state => state.ecolyo.challenge)
  const exploration: UserExploration | null = currentChallenge
    ? currentChallenge.exploration
    : null

  const ecogestureId: string = exploration ? exploration.ecogesture_id : ''

  const [explorationID, setExplorationID] = useState<string>('')

  useEffect(() => {
    let subscribed = true
    if (
      explorationID &&
      currentChallenge?.exploration.id === explorationID &&
      currentChallenge?.exploration.state === UserExplorationState.ONGOING
    ) {
      const checkExplo = async () => {
        const explorationService = new ExplorationService(client)
        explorationService
          .checkExploration(currentChallenge, explorationID)
          .then(updatedChallenge => {
            dispatch(updateUserChallengeList(updatedChallenge))
            if (
              updatedChallenge.exploration.state ===
              UserExplorationState.NOTIFICATION
            ) {
              dispatch(toggleChallengeExplorationNotification(true))
            }
          })
        if (subscribed) setExplorationID('')
      }
      checkExplo()
    }

    return () => {
      subscribed = false
    }
  }, [
    client,
    exploration,
    explorationID,
    ecogestureId,
    currentChallenge,
    dispatch,
  ])

  return [explorationID, setExplorationID]
}

export default useExploration
