import { Button } from '@material-ui/core'
import { FluidType } from 'enums'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import ExportLoadingModal from './exportLoadingModal'

const mockHandleClose = jest.fn()
const mockHandleDone = jest.fn()
const mockSelectedFluids: FluidType[] = [0, 1, 2]

describe('ExportLoadingModal component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportLoadingModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDone={mockHandleDone}
          selectedFluids={mockSelectedFluids}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should cancel download', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportLoadingModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDone={mockHandleDone}
          selectedFluids={mockSelectedFluids}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHandleClose).toHaveBeenCalledTimes(1)
  })
})
