import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import ExportStartModal from './exportStartModal'

const mockHandleClose = jest.fn()
const mockHandleDownloadClick = jest.fn()

describe('exportStartModal component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportStartModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDownloadClick={mockHandleDownloadClick}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should close modal', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportStartModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDownloadClick={mockHandleDownloadClick}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHandleClose).toHaveBeenCalledTimes(1)
  })
})
