import profileIcon from 'assets/icons/ico/profile.svg'
import StyledCard from 'components/CommonKit/Card/StyledCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import ProfileTypeOptions from 'components/Options/ProfileTypeOptions/ProfileTypeOptions'
import {
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  ThreeChoicesAnswer,
} from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { mockProfileType } from 'tests/__mocks__/profileType.mock'
import {
  createMockEcolyoStore,
  mockChallengeState,
  mockProfileState,
} from 'tests/__mocks__/store'

describe('ProfileTypeOptions component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find(StyledCard).exists()).toBeTruthy()
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    expect(wrapper.find(profileIcon)).toBeTruthy()
    wrapper.find('.profile-link').first().simulate('click')
  })
  it('should be rendered when user complete profile type form', () => {
    const store = createMockEcolyoStore({
      profile: { ...mockProfileState, isProfileTypeCompleted: true },
      profileType: mockProfileType,
      challenge: mockChallengeState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.profile-container').exists()).toBeTruthy()
  })
  it('should be rendered when housing_type = apartment', () => {
    const store = createMockEcolyoStore({
      profile: { ...mockProfileState, isProfileTypeCompleted: true },
      profileType: { ...mockProfileType, housingType: HousingType.APARTMENT },
      challenge: mockChallengeState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.floor').exists()).toBeTruthy()
  })
  it('should display heating with equipments', () => {
    const store = createMockEcolyoStore({
      profile: { ...mockProfileState, isProfileTypeCompleted: true },
      profileType: {
        ...mockProfileType,
        heating: IndividualOrCollective.INDIVIDUAL,
        housingType: HousingType.APARTMENT,
        hasInstalledVentilation: ThreeChoicesAnswer.YES,
        hasReplacedHeater: ThreeChoicesAnswer.YES,
      },
      challenge: mockChallengeState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.equipments').exists()).toBeTruthy()
  })
  it('should display insulation work', () => {
    const store = createMockEcolyoStore({
      profile: {
        ...mockProfileState,
        isProfileTypeCompleted: true,
      },
      profileType: {
        ...mockProfileType,
        housingType: HousingType.APARTMENT,
        individualInsulationWork: [
          IndividualInsulationWork.ROOF_INSULATION,
          IndividualInsulationWork.WINDOW_REPLACEMENT,
        ],
      },
      challenge: mockChallengeState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.insulation').exists()).toBeTruthy()
  })
})
