import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.slice'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import UnSubscribeView from './UnSubscribeView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    updateProfile: mockUpdateProfile,
  }))
})
const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('UnSubscribe component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <UnSubscribeView />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should click on button and deactivate report', () => {
    const wrapper = mount(
      <Provider store={store}>
        <UnSubscribeView />
      </Provider>
    )
    wrapper.find(Button).simulate('click')
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: false,
    })
  })
})
