import { Button } from '@material-ui/core'
import { FluidType } from 'enums'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import PartnerIssueModal from './PartnerIssueModal'

const mockHandleClose = jest.fn()
describe('PartnerIssueModal component', () => {
  it('should render correctly', () => {
    const wrapper = mount(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render elec modal', () => {
    const wrapper = mount(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(wrapper.text().includes('error_connect_elec')).toBeTruthy()
  })
  it('should render water modal', () => {
    const wrapper = mount(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.WATER}
      />
    )
    expect(wrapper.text().includes('error_connect_water')).toBeTruthy()
  })
  it('should close modal', () => {
    const wrapper = mount(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    wrapper.find(Button).simulate('click')
    expect(mockHandleClose).toHaveBeenCalled()
  })

  it('should not be rendered', () => {
    const wrapper = mount(
      <PartnerIssueModal
        open={false}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(wrapper.find('div.partnerIssueModal').exists()).toBeFalsy()
  })
})
