import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { UserChallengeUpdateFlag } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizBegin from './QuizBegin'

const mockUserChallengeUpdateFlag = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
  }))
})

describe('QuizBegin component', () => {
  it('should be rendered correctly', () => {
    const store = createMockEcolyoStore()
    const wrapper = mount(
      <Provider store={store}>
        <QuizBegin userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    wrapper.find('.button-start').find(Button).simulate('click')
    expect(mockUserChallengeUpdateFlag).toHaveBeenCalledWith(
      userChallengeData[0],
      UserChallengeUpdateFlag.QUIZ_START
    )
  })
})
