import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { UserChallengeUpdateFlag } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { waitForComponentToPaint } from 'tests/__mocks__/testUtils'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizFinish from './QuizFinish'

const mockUserChallengeUpdateFlag = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
  }))
})

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('QuizFinish', () => {
  it('should be rendered correctly', async () => {
    const store = createMockEcolyoStore()
    const wrapper = mount(
      <Provider store={store}>
        <QuizFinish userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    wrapper.find(Button).forEach(node => {
      node.simulate('click')
    })
    expect(mockUserChallengeUpdateFlag).toHaveBeenCalledWith(
      userChallengeData[0],
      UserChallengeUpdateFlag.QUIZ_RESET
    )
    await waitForComponentToPaint(wrapper)

    expect(mockedNavigate).toHaveBeenCalledWith('/challenges')
  })
})
