/* eslint-disable react/display-name */
import { UserQuestionState } from 'enums'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizQuestion from './QuizQuestion'

const mockgetCustomQuestion = jest.fn()
jest.mock('services/quiz.service', () => {
  return jest.fn(() => {
    return {
      getCustomQuestion: mockgetCustomQuestion,
    }
  })
})

jest.mock(
  'components/Quiz/QuizQuestion/QuizQuestionContentCustom',
  () => () => <div id="QuizQuestionContentCustom" />
)
jest.mock('components/Quiz/QuizQuestion/QuizQuestionContent', () => () => (
  <div id="quizquestioncontent" />
))

describe('QuizQuestion component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })

  it('should be rendered correctly with question', () => {
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestion userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('#quizquestioncontent').exists()).toBeTruthy()
    expect(wrapper.find('#QuizQuestionContentCustom').exists()).toBeFalsy()
  })

  it('should be rendered correctly with customQuestion', () => {
    const updateUserChallengeData = {
      ...userChallengeData[0],
    }
    updateUserChallengeData.quiz.questions.forEach(
      answer => (answer.result = UserQuestionState.CORRECT)
    )
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestion userChallenge={updateUserChallengeData} />
      </Provider>
    )
    expect(wrapper.find('#quizquestioncontent').exists()).toBeFalsy()
    expect(wrapper.find('#QuizQuestionContentCustom').exists()).toBeTruthy()
  })
})
