import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizQuestionContent from './QuizQuestionContent'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockUpdateUserQuiz = jest.fn()
jest.mock('services/quiz.service', () => {
  return jest.fn(() => ({
    updateUserQuiz: mockUpdateUserQuiz,
  }))
})

const mockUserChallengeUpdateFlag = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
  }))
})

describe('QuizQuestionContent component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
        />
      </Provider>
    )
    expect(wrapper.find('.question').text()).toEqual(
      userChallengeData[0].quiz.questions[0].questionLabel
    )
    expect(wrapper.find('input')).toHaveLength(3)
  })
  it('should redirect to challenge on click on btn-back', () => {
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
        />
      </Provider>
    )

    wrapper.find('.btn-back').first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/challenges')
  })
})
