import QuizView from 'components/Quiz/QuizView'
import { UserQuizState } from 'enums'
import { mount } from 'enzyme'
import { ChallengeState } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import { challengeStateData } from 'tests/__mocks__/challengeStateData.mock'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizBegin from './QuizBegin/QuizBegin'
import QuizFinish from './QuizFinish/QuizFinish'
import QuizQuestion from './QuizQuestion/QuizQuestion'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

describe('QuizView component', () => {
  it('should be rendered with QuizBegin component when quiz state = unlocked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.UNLOCKED },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({
      challenge: updatedChallengeState,
      global: mockGlobalState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizView />
      </Provider>
    )
    expect(wrapper.find(QuizBegin).exists()).toBeTruthy()
  })

  it('should be rendered with QuizQuestion component when quiz state = ongoing', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.ONGOING },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({
      challenge: updatedChallengeState,
      global: mockGlobalState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizView />
      </Provider>
    )
    expect(wrapper.find(QuizQuestion).exists()).toBeTruthy()
  })

  it('should be rendered with QuizFinish component when quiz state = done', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.DONE },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    const store = createMockEcolyoStore({
      challenge: updatedChallengeState,
      global: mockGlobalState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizView />
      </Provider>
    )
    expect(wrapper.find(QuizFinish).exists()).toBeTruthy()
  })

  it('should be rendered with QuizBegin component when quiz state = null', () => {
    const updatedChallengeState: ChallengeState = {
      ...challengeStateData,
      currentChallenge: {
        ...userChallengeData[0],
        quiz: { ...userChallengeData[0].quiz, state: UserQuizState.UNLOCKED },
      },
    }
    const store = createMockEcolyoStore({
      challenge: updatedChallengeState,
      global: mockGlobalState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizView />
      </Provider>
    )
    expect(wrapper.find(QuizBegin).exists()).toBeTruthy()
  })
})
