import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { mockUpToDateTerm } from 'tests/__mocks__/termsData.mock'
import TermsView from './TermsView'

const mockCreateTerm = jest.fn()
const mockGetTermsVersionType = jest.fn()
jest.mock('services/terms.service', () => {
  return jest.fn(() => ({
    createTerm: mockCreateTerm,
    getTermsVersionType: mockGetTermsVersionType,
  }))
})

const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    updateProfile: mockUpdateProfile,
  }))
})

describe('TermsView component', () => {
  const store = createMockEcolyoStore()
  it('should valid checkboxes and valid consent', () => {
    mockCreateTerm.mockResolvedValueOnce(mockUpToDateTerm)
    const wrapper = mount(
      <Provider store={store}>
        <TermsView />
      </Provider>
    )

    wrapper
      .find('input')
      .at(0)
      .simulate('change', { target: { checked: true } })
    expect(wrapper.find('input').at(0).props().checked).toEqual(true)
    wrapper
      .find('input')
      .at(1)
      .simulate('change', { target: { checked: true } })
    expect(wrapper.find('input').at(1).props().checked).toEqual(true)
    expect(wrapper.find(Button).first().hasClass('disabled')).toBeFalsy()
    wrapper.find(Button).first().simulate('click')
    expect(mockAppDispatch).toHaveBeenCalledTimes(3)
  })
  it('should be rendered correctly', () => {
    const component = mount(
      <Provider store={store}>
        <TermsView />
      </Provider>
    )
    expect(toJson(component)).toMatchSnapshot()
  })
  it('should be unable to valid consent', async () => {
    mockCreateTerm.mockResolvedValueOnce(mockUpToDateTerm)
    const wrapper = mount(
      <Provider store={store}>
        <TermsView />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')

    expect(wrapper.find(Button).first().hasClass('disabled')).toBeTruthy()
    expect(mockUpdateProfile).toHaveBeenCalledTimes(0)
  })
})
