/* eslint-disable @typescript-eslint/no-explicit-any */
/* eslint-disable @typescript-eslint/no-var-requires */
declare let __PIWIK_TRACKER_URL__: string
declare let __PIWIK_SITEID__: number
declare let __SENTRY_DSN__: string
declare let Piwik: any

import * as Sentry from '@sentry/react'
import { BrowserTracing } from '@sentry/tracing'
import CozyClient, { Client, CozyProvider } from 'cozy-client'
import { isFlagshipApp } from 'cozy-device-helper'
import { handleOAuthResponse } from 'cozy-harvest-lib/dist/helpers/oauth'
import { WebviewIntentProvider } from 'cozy-intent'
import { I18n, initTranslation } from 'cozy-ui/transpiled/react/I18n'
import schema from 'doctypes'
import { History, createHashHistory } from 'history'
import { memoize } from 'lodash'
import React from 'react'
import { render } from 'react-dom'
import { Provider } from 'react-redux'
import { HashRouter } from 'react-router-dom'
import EnvironmentService from 'services/environment.service'
import { setupStore } from 'store/store'
import cozyBar from 'utils/cozyBar'
import logApp from 'utils/logger'
import MatomoTracker from 'utils/matomoTracker'
import manifest from '../../../manifest.webapp'
import '../../styles/index.scss'

const setupApp = memoize(() => {
  const history: History = createHashHistory()
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const root: any = document.querySelector('[role=application]')
  const data = JSON.parse(root.dataset.cozy)
  const protocol = window.location.protocol
  const cozyUrl = `${protocol}//${data.domain}`

  const locale = 'fr'
  const polyglot: any = initTranslation(locale, lang =>
    require(`locales/${lang}`)
  )

  const client: Client = new CozyClient({
    uri: cozyUrl,
    token: data.token,
    appMetadata: {
      slug: manifest.name,
      version: manifest.version,
    },
    schema,
  })

  const store = setupStore(client)
  const envService = new EnvironmentService()
  const isLocal = envService.isLocal()
  const development = envService.isDev()

  cozyBar.init({
    appName: data.app.name,
    appEditor: data.app.editor,
    cozyClient: client,
    iconPath: data.app.icon,
    lang: data.locale,
    replaceTitleOnMobile: false,
    appSlug: data.app.slug,
    appNamePrefix: data.app.prefix,
    isInvertedTheme: isFlagshipApp(),
  })

  let tracker: undefined | MatomoTracker
  if (window.Piwik) {
    Piwik.getTracker()
    tracker = new MatomoTracker({
      cozyUrl: cozyUrl,
      url: __PIWIK_TRACKER_URL__,
      siteId: __PIWIK_SITEID__,
      history: history,
      phpFilename: 'matomo.php',
    })
  }

  !isLocal &&
    Sentry.init({
      dsn: __SENTRY_DSN__,
      integrations: [new BrowserTracing()],
      // Set tracesSampleRate to 1.0 to capture 100%
      // of transactions for performance monitoring.
      // We recommend adjusting this value in production
      // Set to 0 for local development
      tracesSampleRate: 1.0,

      // Custom settings below
      release: client.appMetadata.version,
      environment: development ? 'development' : 'production',
      // cast because init is somehow missing dsn property
    } as Sentry.BrowserOptions)

  return { root, store, client, locale, polyglot, history, tracker }
})

const init = () => {
  const { root, store, client, locale, polyglot, history, tracker } = setupApp()

  if (handleOAuthResponse()) return
  const App = require('components/App').default
  render(
    <WebviewIntentProvider setBarContext={cozyBar.setWebviewContext}>
      <Provider store={store}>
        <CozyProvider client={client}>
          <I18n lang={locale} polyglot={polyglot}>
            <HashRouter {...history}>
              <App tracker={tracker} />
            </HashRouter>
          </I18n>
        </CozyProvider>
      </Provider>
    </WebviewIntentProvider>,
    root
  )
}

// initial rendering of the application
document.addEventListener('DOMContentLoaded', () => init())
// excludes Chrome, Edge, and all Android browsers that include the Safari name in their user agent
const isSafari = /^((?!chrome|android).)*safari/i.test(navigator.userAgent)
if (!isSafari && 'serviceWorker' in navigator) {
  window.addEventListener('load', function () {
    navigator.serviceWorker
      .register('/serviceWorker.js')
      .then(reg => console.log('service worker registered', reg.scope))
      .catch(error => {
        const errorMessage = `service worker not registered: ${JSON.stringify(
          error
        )}`
        logApp.error(errorMessage)
        Sentry.captureException(errorMessage)
      })
  })
}

if (module.hot) {
  init()
  module.hot.accept()
}
