import AddElecIcon from 'assets/icons/ico/add-elec.svg'
import AddGasIcon from 'assets/icons/ico/add-gas.svg'
import AddWaterIcon from 'assets/icons/ico/add-water.svg'
import iconEglWhiteLogo from 'assets/icons/visu/egl-logo-white.svg'
import iconEglLogo from 'assets/icons/visu/egl-logo.svg'
import ElecParamIcon from 'assets/icons/visu/elec-param.svg'
import iconEnedisWhiteLogo from 'assets/icons/visu/enedis-logo-white.svg'
import iconEnedisLogo from 'assets/icons/visu/enedis-logo.svg'
import GasParamIcon from 'assets/icons/visu/gas-param.svg'
import iconGrdfWhiteLogo from 'assets/icons/visu/grdf-logo-white.svg'
import iconGrdfLogo from 'assets/icons/visu/grdf-logo.svg'
import MultiIcon from 'assets/icons/visu/multi-icon.svg'
import WaterParamIcon from 'assets/icons/visu/water-param.svg'
import { FluidType } from 'enums'
import ElecSmallIcon from '../assets/icons/visu/elec-small.svg'
import ElecIcon from '../assets/icons/visu/elec.svg'
import GasSmallIcon from '../assets/icons/visu/gas-small.svg'
import GasIcon from '../assets/icons/visu/gas.svg'
import WaterSmallIcon from '../assets/icons/visu/water-small.svg'
import WaterIcon from '../assets/icons/visu/water.svg'
import { getAddPicto, getParamPicto, getPartnerPicto, getPicto } from './picto'

const unknownFluidType = 99 as FluidType

describe('picto utils test', () => {
  describe('getPicto test', () => {
    describe('case ELECTRICITY', () => {
      it('should return Electricity Icon', () => {
        const result = getPicto(FluidType.ELECTRICITY)
        expect(result).toBe(ElecIcon)
      })

      it('should return Small electricity icon', () => {
        const result = getPicto(FluidType.ELECTRICITY, true)
        expect(result).toBe(ElecSmallIcon)
      })
    })

    describe('case WATER', () => {
      it('should return water Icon', () => {
        const result = getPicto(FluidType.WATER)
        expect(result).toBe(WaterIcon)
      })

      it('should return Small water icon', () => {
        const result = getPicto(FluidType.WATER, true)
        expect(result).toBe(WaterSmallIcon)
      })
    })

    describe('case GAS', () => {
      it('should return gas Icon', () => {
        const result = getPicto(FluidType.GAS)
        expect(result).toBe(GasIcon)
      })

      it('should return Small gas icon', () => {
        const result = getPicto(FluidType.GAS, true)
        expect(result).toBe(GasSmallIcon)
      })
    })
    describe('case MULTI', () => {
      it('should return multifluid Icon', () => {
        const result = getPicto(FluidType.MULTIFLUID)
        expect(result).toBe(MultiIcon)
      })
    })
    describe('case default', () => {
      it('should return default Icon', () => {
        const result = getPicto(unknownFluidType)
        expect(result).toBe(ElecIcon)
      })
    })
  })

  describe('getAddPicto test', () => {
    it('should return add electricity icon', () => {
      const result = getAddPicto(FluidType.ELECTRICITY)
      expect(result).toBe(AddElecIcon)
    })

    it('should return add water icon', () => {
      const result = getAddPicto(FluidType.WATER)
      expect(result).toBe(AddWaterIcon)
    })

    it('should return add gas icon', () => {
      const result = getAddPicto(FluidType.GAS)
      expect(result).toBe(AddGasIcon)
    })
    it('should return default Icon', () => {
      const result = getPicto(unknownFluidType)
      expect(result).toBe(ElecIcon)
    })
  })

  describe('getParamPicto test', () => {
    it('should return param electricity icon', () => {
      const result = getParamPicto(FluidType.ELECTRICITY)
      expect(result).toBe(ElecParamIcon)
    })

    it('should return param water icon', () => {
      const result = getParamPicto(FluidType.WATER)
      expect(result).toBe(WaterParamIcon)
    })

    it('should return param gas icon', () => {
      const result = getParamPicto(FluidType.GAS)
      expect(result).toBe(GasParamIcon)
    })
    it('should return default Icon', () => {
      const result = getPicto(unknownFluidType)
      expect(result).toBe(ElecParamIcon)
    })
  })

  describe('getPartnerPicto test', () => {
    it('should return enedis logo icon', () => {
      const result = getPartnerPicto('enedissgegrandlyon', false)
      expect(result).toBe(iconEnedisLogo)
    })
    it('should return white enedis logo icon', () => {
      const result = getPartnerPicto('enedissgegrandlyon', true)
      expect(result).toBe(iconEnedisWhiteLogo)
    })
    it('should return egl logo icon', () => {
      const result = getPartnerPicto('eglgrandlyon', false)
      expect(result).toBe(iconEglLogo)
    })
    it('should return white egl logo icon', () => {
      const result = getPartnerPicto('eglgrandlyon', true)
      expect(result).toBe(iconEglWhiteLogo)
    })
    it('should return grdf logo icon', () => {
      const result = getPartnerPicto('grdfgrandlyon', false)
      expect(result).toBe(iconGrdfLogo)
    })
    it('should return white grdf logo icon', () => {
      const result = getPartnerPicto('grdfgrandlyon', true)
      expect(result).toBe(iconGrdfWhiteLogo)
    })
    it('should return default Icon', () => {
      const result = getPartnerPicto('', false)
      expect(result).toBe('')
    })
  })
})
